brickwork library

Classes

ApiUrl
App
AppAlertDialog
AppApiFailureScreen
AppButton
Button with text displayed in the application.
AppColors
Defines the color palette for the App UI Kit.
AppColorSchemes
AppDioLogger
AppGlobalConstants
AppLists
AppLoadingWidget
AppRoutes
AppTextStyles
AuthController
AuthInterceptor
  • Create default header
  • Add token if exists
  • Add other header params if passed
  • Logout user if _tokenExpiryCode or _refreshTokenExpired
  • Navigate to user to AppApiFailureScreen when no internet connection is available
  • Navigate to user to AppServerMantainenceScreen when server is down
  • AuthRepository
    AutoOtp
    ConnectionUtil
    CryptoInterceptor
    Interceptor for encrypting and decrypting the API Request and response
    CustomConsoleOutput
    Extends 'LogOutput' to correctly display console colors on macOS systems.
    DioUtil
    EmailValidation
    Failure<S, E extends Exception>
    LocalStorageManager
    LoginScreen
    RefreshTokenInterceptor
    Refresh the token if _refreshTokenErrorCode Retry all the failed requests
    Result<S, E extends Exception>
    Base Result class S represents the type of the success value E should be Exception or a subclass of it
    RetryOnConnectionChangeInterceptor
    SizeConfig
    SplashScreen
    StoreConfig
    Success<S, E extends Exception>
    User
    UserRegisterResponse

    Mixins

    GenerateRoute

    Constants

    maxUserAge → const int
    minUserAge → const int

    Properties

    logger → Logger
    final
    loggerNoStack → Logger
    final
    loggerNoStackBox → Logger
    final

    Functions

    capitalizeFirst(String s) String
    generateYearsList() List<String>
    getCurrentRounteAndArgs(GlobalKey<NavigatorState> navigatorKey) → (String?, Object?)
    This method is used for the facebook authentication After successful authentication this method returns a FbInfo model FbInfo model includes accesstoken for fb and name of user.
    getDioExceptionWithData({int? statusCode, dynamic data}) → DioException
    getDioSuccessResponse({int? statusCode, dynamic data}) → Response
    init(Map<String, dynamic> data) Future<void>
    isBlank(dynamic value) bool?
    isNull(dynamic value) bool
    parseJwt(String token) Map<String, dynamic>
    showAnimatedDialog({required String label, required BuildContext context, required Widget child}) → void