Gender enum

Inheritance
Available extensions

Values

male → const Gender
female → const Gender
other → const Gender

Properties

groupFromGender String
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
pronouns String

Available on Gender, provided by the GenderExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toLowerCase String

Available on Gender, provided by the GenderExt extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Gender>
A constant List of the values in this enum, in order of their declaration.